@@ -1,14 +1,15 @@
 use chrono::{DateTime, Local, Utc, Timelike, Duration};
-use log::Level;
+use log::{LevelFilter};
 use std::time::SystemTime;
 use std::ops::{Add, Sub};
+use crate::appender::Command::CommandRecord;
 
 /// LogAppender append logs
 /// Appender will be running on single main thread,please do_log for new thread or new an Future
 pub trait LogAppender: Send {
     /// this method use one coroutines run this(Multiple appenders share one Appender).
     /// so. if you want  access the network, you can launch a coroutine using go! (| | {});
-    fn do_log(&self, record: &mut FastLogRecord);
+    fn do_log(&self, record: &FastLogRecord);
 
     fn type_name(&self) -> &'static str {
         std::any::type_name::<Self>()
@@ -38,22 +39,23 @@ pub struct FastLogRecord {
 
 /// format record data
 pub trait RecordFormat: Send + Sync {
-    fn do_format(&self, arg: &mut FastLogRecord)->String;
+    fn do_format(&self, arg: &mut FastLogRecord) -> String;
 }
 
 pub struct FastLogFormatRecord {
     pub duration: Duration,
+    pub display_file: log::LevelFilter,
 }
 
 impl RecordFormat for FastLogFormatRecord {
-    fn do_format(&self, arg: &mut FastLogRecord) ->String{
-        let data;
-        let now: DateTime<Utc> = chrono::DateTime::from(arg.now);
-        let now = now.add(self.duration).naive_utc().to_string();
-        match arg.level {
-            Level::Warn | Level::Error => {
+    fn do_format(&self, arg: &mut FastLogRecord) -> String {
+        if arg.command.eq(&CommandRecord) {
+            let data;
+            let now: DateTime<Utc> = chrono::DateTime::from(arg.now);
+            let now = now.add(self.duration).naive_utc().to_string();
+            if arg.level.to_level_filter() <= self.display_file {
                 data = format!(
-                    "{:30} {} {} - {}  {}:{}\n",
+                    "{:26} {} {} - {}  {}:{}\n",
                     &now,
                     arg.level,
                     arg.module_path,
@@ -61,20 +63,19 @@ impl RecordFormat for FastLogFormatRecord {
                     arg.file,
                     arg.line.unwrap_or_default()
                 );
-            }
-            _ => {
+            } else {
                 data = format!(
-                    "{:30} {} {} - {}\n",
+                    "{:26} {} {} - {}\n",
                     &now, arg.level, arg.module_path, arg.args
                 );
             }
+            return data;
         }
-        data
+        return String::new();
     }
 }
 
 impl FastLogFormatRecord {
-
     pub fn local_duration() -> Duration {
         let utc = chrono::Utc::now().naive_utc();
         let tz = chrono::Local::now().naive_local();
@@ -83,40 +84,8 @@ impl FastLogFormatRecord {
 
     pub fn new() -> FastLogFormatRecord {
         Self {
-            duration: Self::local_duration()
+            duration: Self::local_duration(),
+            display_file: LevelFilter::Warn,
         }
     }
-}
-
-// #[cfg(test)]
-// mod test {
-//     use std::time::{Instant, SystemTime};
-//     use log::Level;
-//     use crate::appender::{Command, FastLogFormatRecord, FastLogRecord, RecordFormat};
-//     use crate::bencher::QPS;
-//
-//     #[test]
-//     fn test_bench() {
-//         let arg = FastLogFormatRecord::new();
-//         let mut a = FastLogRecord {
-//             command: Command::CommandRecord,
-//             level: Level::Error,
-//             target: "".to_string(),
-//             args: "".to_string(),
-//             module_path: "".to_string(),
-//             file: "".to_string(),
-//             line: None,
-//             now: SystemTime::now(),
-//             formated: "".to_string(),
-//         };
-//         let total = 10000;
-//         let now = Instant::now();
-//         for index in 0..total {
-//             //use Time: 5.6558ms ,each:565 ns/op
-//             //use QPS: 1761897 QPS/s
-//             arg.do_format(&mut a);
-//         }
-//         now.time(total);
-//         now.qps(total);
-//     }
-// }
\ No newline at end of file
+}
\ No newline at end of file
