@@ -4,7 +4,7 @@ use crate::appender::{FastLogRecord, LogAppender};
 pub struct ConsoleAppender {}
 
 impl LogAppender for ConsoleAppender {
-    fn do_log(&self, record: &mut FastLogRecord) {
+    fn do_log(&self, record: &FastLogRecord) {
         print!("{}", record.formated);
     }
 }
