@@ -2,6 +2,24 @@ use crate::plugin::file_split::Packer;
 use std::fs::File;
 use crate::error::LogError;
 use std::io::{BufReader, Write, BufRead, Error};
+use std::io::prelude::*;
+
+/// keep temp{date}.log
+pub struct LogPacker {
+
+}
+impl Packer for LogPacker {
+    fn pack_name(&self) -> &'static str {
+        "log"
+    }
+
+    fn do_pack(&self, mut log_file: File, log_file_path: &str) -> Result<bool, LogError> {
+        //do nothing,and not remove file
+        return Ok(false);
+    }
+}
+
+
 
 #[cfg(feature = "zip")]
 use zip::write::FileOptions;
@@ -19,7 +37,7 @@ impl Packer for ZipPacker {
         "zip"
     }
 
-    fn do_pack(&self, log_file: File, log_file_path: &str) -> Result<(), LogError> {
+    fn do_pack(&self, mut log_file: File, log_file_path: &str) -> Result<bool, LogError> {
         let mut log_name = log_file_path.replace("\\", "/").to_string();
         if let Some(v) = log_file_path.rfind("/") {
             log_name = log_name[(v + 1)..log_name.len()].to_string();
@@ -38,22 +56,14 @@ impl Packer for ZipPacker {
         let mut zip = zip::ZipWriter::new(zip_file);
         zip.start_file(log_name, FileOptions::default());
         //buf reader
-        let mut r = BufReader::new(log_file);
-        let mut buf = String::new();
-        while let Ok(l) = r.read_line(&mut buf) {
-            if l == 0 {
-                break;
-            }
-            zip.write(buf.as_bytes());
-            buf.clear();
-        }
+        std::io::copy(&mut log_file,&mut zip);
         zip.flush();
         let finish: ZipResult<File> = zip.finish();
         if finish.is_err() {
             //println!("[fast_log] try zip fail{:?}", finish.err());
             return Err(LogError::from(format!("[fast_log] try zip fail{:?}", finish.err())));
         }
-        return Ok(());
+        return Ok(true);
     }
 }
 
@@ -79,7 +89,7 @@ impl Packer for LZ4Packer {
         "lz4"
     }
 
-    fn do_pack(&self, log_file: File, log_file_path: &str) -> Result<(), LogError> {
+    fn do_pack(&self, mut log_file: File, log_file_path: &str) -> Result<bool, LogError> {
         let mut log_name = log_file_path.replace("\\", "/").to_string();
         if let Some(v) = log_file_path.rfind("/") {
             log_name = log_name[(v + 1)..log_name.len()].to_string();
@@ -101,19 +111,54 @@ impl Packer for LZ4Packer {
             .build(lz4_file)?;
         // io::copy(&mut lz4_file, &mut encoder)?;
         //buf reader
-        let mut r = BufReader::new(log_file);
-        let mut buf = String::new();
-        while let Ok(l) = r.read_line(&mut buf) {
-            if l == 0 {
-                break;
-            }
-            encoder.write(buf.as_bytes());
-            buf.clear();
-        }
+        std::io::copy(&mut log_file,&mut encoder);
         let (_output, result) = encoder.finish();
         if result.is_err() {
             return Err(LogError::from(format!("[fast_log] try zip fail{:?}", result.err())));
         }
-        return Ok(());
+        return Ok(true);
+    }
+}
+
+
+#[cfg(feature = "gzip")]
+use flate2::write::GzEncoder;
+#[cfg(feature = "gzip")]
+use flate2::Compression;
+
+
+#[cfg(feature = "gzip")]
+pub struct GZipPacker {}
+
+#[cfg(feature = "gzip")]
+impl Packer for GZipPacker{
+    fn pack_name(&self) -> &'static str {
+        "gz"
+    }
+
+    fn do_pack(&self, mut log_file: File, log_file_path: &str) -> Result<bool, LogError> {
+        let mut log_name = log_file_path.replace("\\", "/").to_string();
+        if let Some(v) = log_file_path.rfind("/") {
+            log_name = log_name[(v + 1)..log_name.len()].to_string();
+        }
+        let zip_path = log_file_path.replace(".log", ".gz");
+        let zip_file = std::fs::File::create(&zip_path);
+        if zip_file.is_err() {
+            return Err(LogError::from(format!(
+                "[fast_log] create(&{}) fail:{}",
+                zip_path,
+                zip_file.err().unwrap()
+            )));
+        }
+        let mut zip_file = zip_file.unwrap();
+        //write zip bytes data
+        let mut zip = GzEncoder::new(&zip_file,Compression::default());
+        std::io::copy(&mut log_file,&mut zip);
+        zip.flush();
+        let finish = zip.finish();
+        if finish.is_err() {
+            return Err(LogError::from(format!("[fast_log] try zip fail{:?}", finish.err())));
+        }
+        return Ok(true);
     }
 }
\ No newline at end of file
